@@ -1,4 +1,4 @@
-# By A7rf - Rewrited again by SirLez - Rewrited again by Bovonos ._.
+# By A7rf - Rewrited again by SirLez - Rewrited again by Bovonos ._. - Rewrited again by SirLez ,_,
 # SirLez: I know there is no property func
 
 class Login:
@@ -155,9 +155,9 @@ class Message:
         try:  self.clientRefId = data['clientRefId']
         except (KeyError): self.clientRefId = None
         try: self.author: UserInfo = UserInfo(data["author"])
-        except (KeyError): self.author = None
+        except (KeyError): self.author: UserInfo = UserInfo([])
         try: self.replyMessage: ReplyMessage = ReplyMessage(data["extensions"]["replyMessage"])
-        except (KeyError): self.replyMessage = None
+        except (KeyError): self.replyMessage: ReplyMessage = ReplyMessage({})
         try: self.chatId = data["threadId"]
         except (KeyError): self.chatId = None
 
@@ -265,7 +265,8 @@ class BlogListAll:
         try: self.content.append(o["content"])
         except KeyError: pass
 
-      self.author: UserList = UserList(_author)
+      try: self.author: UserList = UserList(_author)
+      except (KeyError): self.author: UserList = UserList({})
 
 
 class ReplyMessage:
@@ -407,3 +408,37 @@ class BubbleTemplates:
             except (KeyError): self.name.append(None)
             try: self.config = BubbleConfig(x["config"])
             except (KeyError): self.config = BubbleConfig({})
+
+
+class RepInfo:
+    def __init__(self, data):
+        self.json = data
+        try: self.availableReputation = data["availableReputation"]
+        except (KeyError): self.availableReputation = None
+        try: self.reputation = data["reputation"]
+        except (KeyError): self.reputation = None
+
+
+class Rep:
+    def __init__(self, data):
+        self.json = data
+        try: self.totalReputation = data["totalReputation"]
+        except (KeyError): self.totalReputation = None
+        try: self.participantCount = data["participantCount"]
+        except (KeyError): self.participantCount = None
+
+
+class Account:
+    def __init__(self, data):
+        self.json = data
+
+        try: self.email = data["email"]
+        except (KeyError): self.email = None
+        try: self.icon = data["icon"]
+        except (KeyError): self.icon = None
+        try: self.nickname = data["nickname"]
+        except (KeyError): self.nickname = None
+        try: self.aminoId = data["aminoId"]
+        except (KeyError): self.aminoId = None
+        try: self.userId = data["uid"]
+        except (KeyError): self.userId = None
