@@ -1,23 +1,24 @@
-import time
 import json
+import requests
 import websocket
 from threading import Thread
 
 from .local import Local
-from .lib import Event, UserInfo
+from .lib import Event, UserInfo, CheckExceptions
 from sys import _getframe as getframe
+
 # By SirLez
 # Solved By SirLez
-# and Reworked By SirLez lol ._.
+# and Sloved By Bovonos ،_،
+# and Reworked By SirLez ._.
+# Note: socket2 is a socket to send & recv data ! ( Do Not load the data with json )
 
 
 class Socket:
     def __init__(self, client):
         self.socket_url = "wss://ws1.narvii.com"
-        websocket.enableTrace(False)
         self.client = client
-        global Client
-        Client = client
+        websocket.enableTrace(False)
 
     def handle_message(self, data):
         self.client.handle(data)
@@ -25,29 +26,32 @@ class Socket:
 
     def on_error(self, error): print(error)
     def on_close(self): print("__CLOSED__")
+    def send(self, data): self.socket2.send(json.dumps(data))
+    def recv(self): return json.loads(self.socket2.recv())
 
-    def launch(self):
-        self.headers = {
-            'NDCDEVICEID': self.client.deviceId,
-            'NDCAUTH': self.client.sid
-        }
+    def web_socket_url(self):
+        req = requests.get("https://aminoapps.com/api/chat/web-socket-url", headers={'cookie': self.client.sid})
+        if req.status_code != 200: return CheckExceptions(req.json())
+        else:
+            self.socket_url = req.json()["result"]["url"]
+            return self.socket_url
+ 
+    def launch(self, socket2: bool = False):
+        self.headers = {'cookie': self.client.sid}
+        
+        if socket2:
+            self.socket2 = websocket.WebSocket()
+            self.socket2.connect(self.web_socket_url(), header=self.headers)
+            
         self.socket = websocket.WebSocketApp(
-            f"{self.socket_url}/?signbody=22FCB673B848DDD4AD7869E3B374AD3CCE884F8D631C027AE596EC7D614638785015596A6F61A2E3AE%7C{int(time.time() * 1000)}",
+            self.web_socket_url(),
             on_message=self.handle_message,
             on_error=self.on_error,
             on_close=self.on_close,
             header=self.headers
         )
         Thread(target=self.socket.run_forever, kwargs={"ping_interval": 60}).start()
-
-    def join_task(self, comId: str):
-        usersList = []
-        while True:
-            users = Local(comId).get_all_users("recent", 1, 1)
-            for userId, data in zip(users.userId, users.json):
-                data["t"] = "0"
-                if userId in usersList: pass
-                else: Thread(target=self.handle_message, args=(data, )).start(); usersList.append(userId)
+        print("ready!")
 
 
 class Recall:
@@ -75,23 +79,15 @@ class Recall:
             "67": self.on_set_you_cohost,
             "68": self.on_remove_you_cohost
         }
-        self.community_methods = {
-            "0": self.on_community_join
-        }
         self.methods = {
             1000: self.chat_messages,
             10: self.payload,
-            "0": self.community
         }
 
     def payload(self, data):
         value = f"{data['o']['payload']['notifType']}"
         return self.notif_methods.get(value, self.classic)(data)
 
-    def community(self, data):
-        value = data["t"]
-        return self.community_methods.get(value, self.classic)(data)
-
     def chat_messages(self, data):
         value = f"{data['o']['chatMessage']['type']}:{data['o']['chatMessage'].get('mediaType', 0)}"
         return self.chat_methods.get(value, self.classic)(data)
@@ -106,14 +102,11 @@ class Recall:
         if func in self.handlers:
             for handler in self.handlers[func]: handler(data)
 
-    def event(self, func, comId: str = None):
-        global Client
+    def event(self, func):
         def regHandler(handler):
             if func in self.handlers: self.handlers[func].append(handler)
             else: self.handlers[func] = [handler]
             return handler
-        if comId is not None: Thread(target=Socket(Client).join_task, args=(comId, )).start()
-        self.comId = comId
         return regHandler
 
     def on_content_changed(self, data): self.roll(getframe(0).f_code.co_name, Event(data["o"]))
@@ -132,6 +125,5 @@ class Recall:
     def on_chat_donate(self, data): self.roll(getframe(0).f_code.co_name, Event(data["o"]))
     def on_member_join(self, data): self.roll(getframe(0).f_code.co_name, Event(data["o"]))
     def on_member_left(self, data): self.roll(getframe(0).f_code.co_name, Event(data["o"]))
-    def on_community_join(self, data):self.roll(getframe(0).f_code.co_name, UserInfo(data))
     def on_message(self, data): self.roll(getframe(0).f_code.co_name, Event(data["o"]))
     def classic(self, data): self.roll(getframe(0).f_code.co_name, data)
